#!/bin/bash

### Image files and MIME types
EU_FLAG="images/EU_flag-3_colors-lowres.png"
EU_FLAG_MIMETYPE="image/png"
QR_CODE="images/qr_code-hires.png"
QR_CODE_MIMETYPE="image/png"
TITLE=

### Path to the utilities we need
NDEFTOOL="ndeftool"
TAGTOOL="python3 nfcpy/examples/tagtool.py"
 


# Create the NDEF record
echo "Encapsulating the data into a smart poster NDEF"
$NDEFTOOL \
	smp "EU Digital COVID Certificate" \
	load --pack $EU_FLAG tn $EU_FLAG_MIMETYPE id '' \
	txt "$(echo -en 'Surname(s) and forename(s):\n\tTestaaja, Matti Kari')" \
	txt "$(echo -en 'Date of birth:\n\t1995-05-20')" \
	txt "$(echo -en 'Unique certificate identifier:\n\tURN:UVCI:01:FI:41EPCEEXEDR3TZV5RW9XQIR15#2')" \
	load --pack $QR_CODE tn $QR_CODE_MIMETYPE id ''\
	txt "VACCINATION CERTIFICATE" \
	txt "$(echo -en 'Disease or agent targeted:\n\tCOVID-19')" \
	txt "$(echo -en 'Vaccine:\n\tCOVID-19 vaccines')" \
	txt "$(echo -en 'Vaccine medicinal product:\n\tComirnaty')" \
	txt "$(echo -en 'Vaccine marketing authorisation holder:\n\tBioNTech Manufacturing GmbH')" \
	txt "$(echo -en 'Number in a series of vaccinations/doses and the overall number of doses in the series:\n\t2/2')" \
	txt "$(echo -en 'Date of vaccination, indicating the date of the latest dose received:\n\t21-03-05')" \
	txt "$(echo -en 'Member state of vaccination:\n\tFinland')" \
	txt "$(echo -en 'Certificate issuer:\n\tThe Social Insurance Institution of Finland\n\tKela/Fpa')" \
	uri "https://www.kanta.fi/documents/20143/120102/mallitodistus_eu_rokotustodistus.pdf/7abaee69-2ec2-7462-85b0-80ab073d9212?t=1623911512376" \
	save --force data.ndef

# Dump the size of the NDEF file, for information
NDEFSIZE=$(wc -c < data.ndef)
echo "NDEF size: $NDEFSIZE bytes"

# Read the tag
echo "Reading the tag"
CARD_INFO=$($TAGTOOL)

# Make sure the tag is writable
if [ ! "$(echo $CARD_INFO | grep -i 'NDEF Capabilities.*writeable *= *yes')" ]; then
  echo "Tag is not writeable!"
  exit -1
fi

# Make sure there's enough room on the tag for the NDEF record
TCAPA=$(echo $CARD_INFO | sed -r 's/^.*NDEF Capabilities.*capacity *= *([0-9]+) byte.*$/\1/')
if [ $TCAPA -lt $NDEFSIZE ]; then
  echo "NDEF size exceeds the tag's capacity ($TCAPA bytes)!"
  exit -1
fi

# Ask the user if they really want to write the NDEF on the tag
read -p "Write NDEF onto the tag [Y/N]? " YN
if [ "$YN" != "y" ] && [ "$YN" != "Y" ]; then
  echo "Aborting"
  exit 0
fi

# Write the NDEF file onto the tag
echo "Writing NDEF onto the tag"
$TAGTOOL load data.ndef

echo "All done!"
